<div>
<p>You are now leaving this website.</p>
<a class="rewrite-external-links-continue-link" href="{{ link }}">Continue</a> 
{% if next %}<a class="rewrite-external-links-cancel-link" href="{{ next }}">Cancel</a>{% endif %}
</div>

